SkipMap

Struct SkipMap 

pub struct SkipMap<K: ?Sized, V: ?Sized, C = Ascend>(/* private fields */);
A fast, ARENA based SkipMap that supports multiple versions, forward and backward iteration.

If you want to use in concurrent environment, you can use multiple_version::sync::SkipMap.